import { EventEmitter, OnInit, AfterViewChecked, ElementRef } from '@angular/core';
import { BasePaginatedResponse, PaginatedRequest } from 'ivy.angular.data';
import { MathHelper } from 'ivy.angular.value-helpers';
/**
 * This component works in the following manner:
 * There are 2 separate things that can fire a pagination update
 *
 * If sthe content div is larger than the container div, scroll functionality will be enabled.
 * When you scroll to the bottom of the overflow, the pagination will execute.
 *
 * Alternatively, there is an issue that occurs when the content div is not larger than the container div.
 * We examine this in the AfterViewChecked event hook.  If the container height == scroll height, then
 * scroll capabilities are not enabled.  As such, we'll continue to fire off pagination updates until either
 * there are no pages or we've begun to enable scroll capabilities by ensuring the content div is larger than
 * the corresponding container div.
 */
export declare class ScrollingLoadComponent implements OnInit, AfterViewChecked {
    private math;
    maxHeight: number;
    countPerLoad: number;
    response: BasePaginatedResponse;
    onScrollBottom: EventEmitter<PaginatedRequest>;
    contentDiv: ElementRef;
    containerDiv: ElementRef;
    constructor(math: MathHelper);
    private req;
    private pageHeight;
    private adjustedHeight;
    onScroll(event: any): void;
    ngOnInit(): void;
    ngAfterViewChecked(): void;
    getHeight(): string;
    private emitPageReq();
    private getTotalPages();
    private incrementPage();
    private nullResponse();
}
