"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var ivy_angular_data_1 = require("ivy.angular.data");
var ivy_angular_value_helpers_1 = require("ivy.angular.value-helpers");
/**
 * This component works in the following manner:
 * There are 2 separate things that can fire a pagination update
 *
 * If sthe content div is larger than the container div, scroll functionality will be enabled.
 * When you scroll to the bottom of the overflow, the pagination will execute.
 *
 * Alternatively, there is an issue that occurs when the content div is not larger than the container div.
 * We examine this in the AfterViewChecked event hook.  If the container height == scroll height, then
 * scroll capabilities are not enabled.  As such, we'll continue to fire off pagination updates until either
 * there are no pages or we've begun to enable scroll capabilities by ensuring the content div is larger than
 * the corresponding container div.
 */
var ScrollingLoadComponent = /** @class */ (function () {
    function ScrollingLoadComponent(math) {
        this.math = math;
        this.onScrollBottom = new core_1.EventEmitter();
        this.req = new ivy_angular_data_1.PaginatedRequest();
    }
    //@HostListener('scroll', ['$event'])
    ScrollingLoadComponent.prototype.onScroll = function (event) {
        // We only want to fire off pagination if we're not already waiting for a response
        // Otherwise, we will screw up the paginated context
        if (this.response != null) {
            // Scroll increment condition
            if (event.target.scrollTop + this.containerDiv.nativeElement.clientHeight == event.target.scrollHeight) {
                this.incrementPage();
            }
        }
    };
    ScrollingLoadComponent.prototype.ngOnInit = function () {
        if (this.countPerLoad != null) {
            this.req.pageCount = this.countPerLoad;
        }
        else {
            // Seems a bit more reasonable than 10
            this.req.pageCount = 5;
        }
        this.emitPageReq();
    };
    ScrollingLoadComponent.prototype.ngAfterViewChecked = function () {
        if (this.response == null)
            return;
        // This value will be correct on the first hit after we populate the response
        if (!this.pageHeight) {
            this.pageHeight = this.containerDiv.nativeElement.clientHeight;
        }
        // Check increment condition
        // Is our container larger than our contents???
        // If so, we need to try and load more contents
        if (this.pageHeight > this.contentDiv.nativeElement.clientHeight) {
            // Are we still waiting on the previous increment to complete???
            if (this.contentDiv.nativeElement.clientHeight != this.adjustedHeight) {
                this.adjustedHeight = this.contentDiv.nativeElement.clientHeight;
                this.incrementPage();
            }
        }
    };
    ScrollingLoadComponent.prototype.getHeight = function () {
        // This seems to raise an issue with ExpressionChangedAfterItHasBeenCheckedError
        // Not exactly sure why, but first we need to have the max-height 100% to determine page height
        // After we have page height, we can set that as the max height
        if (this.maxHeight == null && !this.pageHeight) {
            return '100%';
        }
        else if (this.pageHeight) {
            return this.pageHeight + 'px';
        }
        else {
            return this.maxHeight + 'px';
        }
    };
    ScrollingLoadComponent.prototype.emitPageReq = function () {
        this.onScrollBottom.emit(this.req);
    };
    ScrollingLoadComponent.prototype.getTotalPages = function () {
        return this.math.ceil(this.response.totalCount / this.req.pageCount);
    };
    ScrollingLoadComponent.prototype.incrementPage = function () {
        var _this = this;
        if (this.req.pageNumber < this.getTotalPages()) {
            // Setup loading spinner again
            setTimeout(function () { return _this.nullResponse(); });
            // Ensure we load the next page of data
            this.req.pageNumber++;
            // Emit request
            this.emitPageReq();
        }
    };
    ScrollingLoadComponent.prototype.nullResponse = function () {
        this.response = null;
    };
    __decorate([
        core_1.Input(),
        __metadata("design:type", Number)
    ], ScrollingLoadComponent.prototype, "maxHeight", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", Number)
    ], ScrollingLoadComponent.prototype, "countPerLoad", void 0);
    __decorate([
        core_1.Input(),
        __metadata("design:type", ivy_angular_data_1.BasePaginatedResponse)
    ], ScrollingLoadComponent.prototype, "response", void 0);
    __decorate([
        core_1.Output(),
        __metadata("design:type", core_1.EventEmitter)
    ], ScrollingLoadComponent.prototype, "onScrollBottom", void 0);
    __decorate([
        core_1.ViewChild('scrollcontent'),
        __metadata("design:type", core_1.ElementRef)
    ], ScrollingLoadComponent.prototype, "contentDiv", void 0);
    __decorate([
        core_1.ViewChild('scrollcontainer'),
        __metadata("design:type", core_1.ElementRef)
    ], ScrollingLoadComponent.prototype, "containerDiv", void 0);
    ScrollingLoadComponent = __decorate([
        core_1.Component({
            selector: 'ivy-scrolling-load',
            templateUrl: './scrolling-load.component.html'
        }),
        __metadata("design:paramtypes", [ivy_angular_value_helpers_1.MathHelper])
    ], ScrollingLoadComponent);
    return ScrollingLoadComponent;
}());
exports.ScrollingLoadComponent = ScrollingLoadComponent;
//# sourceMappingURL=scrolling-load.component.js.map